==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkQuadRotationalExtrusionFilter.java <==
// java wrapper for vtkQuadRotationalExtrusionFilter object
//

package vtk;
import vtk.*;

public class vtkQuadRotationalExtrusionFilter extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(int id0);
  public void SetAxis(int id0)
    { SetAxis_2(id0); }

  private native int GetAxisMinValue_3();
  public int GetAxisMinValue()
    { return GetAxisMinValue_3(); }

  private native int GetAxisMaxValue_4();
  public int GetAxisMaxValue()
    { return GetAxisMaxValue_4(); }

  private native int GetAxis_5();
  public int GetAxis()
    { return GetAxis_5(); }

  private native void SetAxisToX_6();
  public void SetAxisToX()
    { SetAxisToX_6(); }

  private native void SetAxisToY_7();
  public void SetAxisToY()
    { SetAxisToY_7(); }

  private native void SetAxisToZ_8();
  public void SetAxisToZ()
    { SetAxisToZ_8(); }

  private native void SetResolution_9(int id0);
  public void SetResolution(int id0)
    { SetResolution_9(id0); }

  private native int GetResolutionMinValue_10();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_10(); }

  private native int GetResolutionMaxValue_11();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_11(); }

  private native int GetResolution_12();
  public int GetResolution()
    { return GetResolution_12(); }

  private native void SetCapping_13(int id0);
  public void SetCapping(int id0)
    { SetCapping_13(id0); }

  private native int GetCapping_14();
  public int GetCapping()
    { return GetCapping_14(); }

  private native void CappingOn_15();
  public void CappingOn()
    { CappingOn_15(); }

  private native void CappingOff_16();
  public void CappingOff()
    { CappingOff_16(); }

  private native void SetDefaultAngle_17(double id0);
  public void SetDefaultAngle(double id0)
    { SetDefaultAngle_17(id0); }

  private native double GetDefaultAngle_18();
  public double GetDefaultAngle()
    { return GetDefaultAngle_18(); }

  private native void RemoveAllPerBlockAngles_19();
  public void RemoveAllPerBlockAngles()
    { RemoveAllPerBlockAngles_19(); }

  private native void AddPerBlockAngle_20(int id0,double id1);
  public void AddPerBlockAngle(int id0,double id1)
    { AddPerBlockAngle_20(id0,id1); }

  private native void SetTranslation_21(double id0);
  public void SetTranslation(double id0)
    { SetTranslation_21(id0); }

  private native double GetTranslation_22();
  public double GetTranslation()
    { return GetTranslation_22(); }

  private native void SetDeltaRadius_23(double id0);
  public void SetDeltaRadius(double id0)
    { SetDeltaRadius_23(id0); }

  private native double GetDeltaRadius_24();
  public double GetDeltaRadius()
    { return GetDeltaRadius_24(); }

  public vtkQuadRotationalExtrusionFilter() { super(); }

  public vtkQuadRotationalExtrusionFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkQuadRotationalExtrusionFilter.java <==
// java wrapper for vtkQuadRotationalExtrusionFilter object
//

package vtk;
import vtk.*;

public class vtkQuadRotationalExtrusionFilter extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(int id0);
  public void SetAxis(int id0)
    { SetAxis_2(id0); }

  private native int GetAxisMinValue_3();
  public int GetAxisMinValue()
    { return GetAxisMinValue_3(); }

  private native int GetAxisMaxValue_4();
  public int GetAxisMaxValue()
    { return GetAxisMaxValue_4(); }

  private native int GetAxis_5();
  public int GetAxis()
    { return GetAxis_5(); }

  private native void SetAxisToX_6();
  public void SetAxisToX()
    { SetAxisToX_6(); }

  private native void SetAxisToY_7();
  public void SetAxisToY()
    { SetAxisToY_7(); }

  private native void SetAxisToZ_8();
  public void SetAxisToZ()
    { SetAxisToZ_8(); }

  private native void SetResolution_9(int id0);
  public void SetResolution(int id0)
    { SetResolution_9(id0); }

  private native int GetResolutionMinValue_10();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_10(); }

  private native int GetResolutionMaxValue_11();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_11(); }

  private native int GetResolution_12();
  public int GetResolution()
    { return GetResolution_12(); }

  private native void SetCapping_13(int id0);
  public void SetCapping(int id0)
    { SetCapping_13(id0); }

  private native int GetCapping_14();
  public int GetCapping()
    { return GetCapping_14(); }

  private native void CappingOn_15();
  public void CappingOn()
    { CappingOn_15(); }

  private native void CappingOff_16();
  public void CappingOff()
    { CappingOff_16(); }

  private native void SetDefaultAngle_17(double id0);
  public void SetDefaultAngle(double id0)
    { SetDefaultAngle_17(id0); }

  private native double GetDefaultAngle_18();
  public double GetDefaultAngle()
    { return GetDefaultAngle_18(); }

  private native void RemoveAllPerBlockAngles_19();
  public void RemoveAllPerBlockAngles()
    { RemoveAllPerBlockAngles_19(); }

  private native void AddPerBlockAngle_20(int id0,double id1);
  public void AddPerBlockAngle(int id0,double id1)
    { AddPerBlockAngle_20(id0,id1); }

  private native void SetTranslation_21(double id0);
  public void SetTranslation(double id0)
    { SetTranslation_21(id0); }

  private native double GetTranslation_22();
  public double GetTranslation()
    { return GetTranslation_22(); }

  private native void SetDeltaRadius_23(double id0);
  public void SetDeltaRadius(double id0)
    { SetDeltaRadius_23(id0); }

  private native double GetDeltaRadius_24();
  public double GetDeltaRadius()
    { return GetDeltaRadius_24(); }

  public vtkQuadRotationalExtrusionFilter() { super(); }

  public vtkQuadRotationalExtrusionFilter(long id) { super(id); }
  public native long   VTKInit();

}
